@@ -84,7 +84,7 @@ def cli():
 
     Create files
     ===================
-    dsf-cli create-files [tester / deploy / cloud_eval / documentation / batch]
+    dsf-cli create-files [tester / deploy / cloud_eval / documentation / batch / trainer]
 
     run server
     ==========
@@ -138,6 +138,10 @@ def cli():
     Create sonar scanner properties file:
 
     dsf-cli create-sonar-file current_project_repo_name
+
+    Install requirements for trainer
+    ================================
+    dsf-cli install_trainer_packages
     """
 # @click.option("--type", prompt="type", help="type of component")
 # @click.option("--project_name", prompt="project_name", help="project_name")
@@ -165,7 +169,8 @@ def generate(gen_type, project_name):
 def create_files(file_type):
     """! Build a file creation function from the incoming file type.
         Args:
-            file_type: A string containing one of the following: [tester / deploy / cloud_eval / documentation / batch]
+            file_type: A string containing one of the following:
+                [tester / deploy / cloud_eval / documentation / batch / trainer]
     """
     try:
         f = globals()["create_%s_files" % file_type]
@@ -258,6 +263,11 @@ def create_batch_files():
     copy_batch_files(directories['main'])
 
 
+def create_trainer_files():
+    """! Create trainer files (created through 'Create project', but can be used as a standalone function) """
+    copy_trainer_files()
+
+
 @cli.command()
 @click.argument('action')
 def dataproc_cluster(action: str):
@@ -638,6 +648,10 @@ def create_folders(project_name):
     create_main_folders('test_schema', 'tester')
     create_main_folders('dsp', 'tester')
     create_main_folders('trainer', 'main')
+    create_main_folders('examples', 'trainer')
+    create_main_folders('datasets', 'trainer')
+    create_main_folders('my_dataset_name', 'datasets')
+    create_main_folders(datetime.today().strftime('%Y%m%d_v1'), 'my_dataset_name')
     create_main_folders('server', 'main')
 
 
@@ -678,6 +692,18 @@ def create_project(project_name):
     create_dsp_file(original_project_name, directories['dsp'], 'get_dataset_options', False)
     create_dsp_file(original_project_name, directories['dsp'], 'add_experiment', False)
 
+    # Create trainer files
+    create_trainer_file(project_name, directories['trainer'], 'custom_dataset', False)
+    create_trainer_file(project_name, directories['trainer'], 'data_module', False)
+    create_trainer_file(project_name, directories['trainer'], 'iterable_dataset', False)
+    create_trainer_file(project_name, directories['trainer'], 'model', False)
+    create_trainer_file(project_name, directories['trainer'], 'network_module', False)
+    create_trainer_file(project_name, directories['trainer'], 'trainer', False)
+    create_trainer_file(project_name, directories['examples'], 'example1_mnist', False, True)
+    create_trainer_file(project_name, directories['examples'], 'example2_wine_quality', False, True)
+    source_path = os.path.join(__location__, 'dsframework/cli/trainer/requirements_trainer.txt')
+    shutil.copyfile(source_path, directories['trainer'] + '/requirements_trainer.txt')
+
     # Create server files
     create_server_file(project_name, directories['server'], 'main', False)
     create_server_file(project_name, directories['server'], 'test_server_post', False)
@@ -771,6 +797,23 @@ def create_tester_file(project_name, folder, test_file_type, createInitFile=True
     replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
 
 
+def create_trainer_file(project_name, folder, test_file_type, createInitFile=True, examples_file=False):
+    """! Create trainer file (read the template and use him to create the new file)
+    @verbatim
+    Args:
+        project_name   : The project name.
+        folder         : The folder we want to create the new file.
+        test_file_type : File type.
+        createInitFile(=True): Create init file - if it doesn't exist.
+    @endverbatim
+    """
+    if not examples_file:
+        data = read_template_file('trainer/' + test_file_type)
+    else:
+        data = read_template_file('trainer/examples/' + test_file_type)
+    replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
+
+
 def create_dsp_file(project_name, folder, test_file_type, createInitFile=True):
     """! Create DSP file (read the template and use him to create the new file)
     @verbatim
@@ -1305,6 +1348,68 @@ def copy_batch_files(main_dir):
                     pass
 
 
+def copy_trainer_files():
+    """! This function will create a trainer environment."""
+
+    project_name = os.getcwd().split('/')[-1]
+    trainer_main_folder = 'trainer/'
+    trainer_datasets_folder = 'trainer/datasets/'
+    trainer_datasets_versions_folder = 'trainer/datasets/my_dataset_name/' + datetime.today().strftime('%Y%m%d_v1') + '/'
+    trainer_examples_folder = 'trainer/examples/'
+
+    trainer_file_list = ["trainer/custom_dataset",
+                         "trainer/data_module",
+                         "trainer/iterable_dataset",
+                         "trainer/model",
+                         "trainer/network_module",
+                         "trainer/trainer",
+                         "trainer/examples/example1_mnist",
+                         "trainer/examples/example2_wine_quality"]
+
+    if not os.path.exists(trainer_main_folder):
+        os.mkdir(trainer_main_folder)
+
+    if not os.path.exists(trainer_datasets_folder):
+        os.makedirs(trainer_datasets_versions_folder)
+
+    if not os.path.exists(trainer_examples_folder):
+        os.mkdir(trainer_examples_folder)
+
+    for filename_path in trainer_file_list:
+        file_only = filename_path.split('/')[-1]
+        parent_folder = filename_path.split('/')[-2]
+
+        dst_folder = ''
+        if parent_folder == 'datasets':
+            dst_folder = trainer_datasets_folder
+        elif parent_folder == 'examples':
+            dst_folder = trainer_examples_folder
+
+        data = read_template_file(filename_path)
+
+        clean_project_name = clean_existing_project_name(project_name)
+        filename_no_underscore = to_capitalize_no_underscore(file_only)
+
+        class_name = clean_project_name + filename_no_underscore
+
+        data = data.replace('generatedClass', class_name)
+        data = data.replace('generatedProjectName', clean_project_name)
+
+        new_file = trainer_main_folder + file_only + ".py"
+        if dst_folder != '':
+            new_file = dst_folder + file_only + ".py"
+
+        if not os.path.isfile(new_file):
+            create_file(new_file, data)
+        else:
+            print(f'File \'{new_file}\' exists, skipping.')
+
+    source_path = os.path.join(__location__, 'dsframework/cli/', 'trainer/requirements_trainer.txt')
+    shutil.copyfile(source_path, trainer_main_folder + '/requirements_trainer.txt')
+
+    print("Creating trainer environment done !")
+
+
 def copy_documentation_files(target_dir):
     """! Copy documentation folder to newly created project.
 
@@ -1329,6 +1434,12 @@ def update_doc_configuration(project_name, target_dir):
     save_file(source_dir, data)
 
 
+@cli.command()
+def install_trainer_packages():
+    command = 'pip install -r trainer/requirements_trainer.txt'
+    subprocess.call(command, shell=True)
+
+
 def to_capitalize_no_underscore(text):
     """! Capitalize each word with no underscore
      for example : Moving from test_name -> TestName"""
