@@ -40,7 +40,7 @@ class ZIDS_Workflow():
         if (not env_type == 'production') and (not env_type == 'staging'):
             command = 'gcloud config get-value account'
             user_email = subprocess.check_output(command, shell=True).decode(sys.stdout.encoding)
-            self.user_email = user_email.split("@")[0]
+            self.user_email = '/' + user_email.split("@")[0]
 
         if self.user_email:
             self.config['user_email'] = self.user_email
@@ -62,9 +62,9 @@ class ZIDS_Workflow():
             self.template_id = self.template_id + '_' + self.unique_template_id
 
         if self.unique_iteration_id:
-            self.folder_path = self.project_name + '/' + self.user_email + '/unique_iteration_id_' + self.unique_iteration_id
+            self.folder_path = self.project_name + self.user_email + '/unique_iteration_id_' + self.unique_iteration_id
         else:
-            self.folder_path = self.project_name + '/' + self.user_email + '/main'
+            self.folder_path = self.project_name + self.user_email + '/main'
 
         self.bucket_path = f'gs://{self.bucket_name}/{self.folder_path}'
         self.project_path = 'projects/{project_id}/regions/{region}'.format(project_id=self.project_id,
