@@ -13,6 +13,23 @@ import requests
 from requests.adapters import HTTPAdapter
 from urllib3 import Retry
 
+##
+# @file worker.py
+# Cloud evaluation worker.
+#
+# Its main function is to run against a model in cloud environment, it runs on docker in parallel to the server.
+#
+# Basically it simulates access to the server in a similar way as in production.
+#
+# It performs the following steps:
+# - Reads dataset from S3
+# - Invoke model on Gunicorn server - /parse /predict
+# - Receives results from server.
+# - Write results to S3
+#
+# Receives two parameters from CLI args:
+# @param input_dataset_filename - Input dataset filename
+# @param output_dataset_filename - Output results filename
 
 service_client = None
 
@@ -25,6 +42,14 @@ endpoint_name = None
               reraise=True)
 @log_on_end(logging.INFO, "Downloading {input_path:s} finished successfully")
 def load_csv(input_path):
+    """! Loads a csv file from S3 bucket
+
+        Args:
+            input_path: Input file path
+        Returns:
+            rows: List of dataset rows.
+
+    """
     with download_file_from_s3(input_path) as csvfile:
     # with open(input_path, newline='') as csvfile:
         input_reader = csv.DictReader(csvfile, delimiter=',')
@@ -34,6 +59,17 @@ def load_csv(input_path):
 
 @log_on_start(logging.DEBUG, "invoke_model on {row}...")
 def invoke_model(row):
+    """! Sends a row of data (from the input dataset) to the model at the specified endpoint.
+
+        This method prepares a header and payload based on a row of data from the dataset, sends it to the server
+        and returns prediction result.
+
+        Args:
+            row: Row of data taken from the input dataset
+
+        Returns:
+            model_prediction - Prediction result in json format.
+    """
     request_payload = service_client.get_request_payload(row)
     headers = service_client.get_request_headers(row)
 
@@ -73,6 +109,16 @@ def invoke_model(row):
               reraise=True)
 @log_on_end(logging.INFO, "Completed working on dataset")
 def work_on(rows):
+    """! The main cloud evaluation method.
+
+        Iterates dataset rows, invokes model and evaluates each row.
+
+        Args:
+            rows: Input dataset
+
+        Returns:
+            rows - Includes prediction and evaluation results.
+    """
     for row in rows:
         # Call model and get prediction
         row['prediction'] = json.dumps(invoke_model(row))
@@ -84,6 +130,14 @@ def work_on(rows):
 
 
 def write_to_s3(csv_content, bucket_name, file_path):
+    """ Uploads file to S3
+
+    Args:
+        csv_content: Csv file in bytes array
+        bucket_name: Bucket name
+        file_path: File output path
+
+    """
     client = boto3.client('s3')
     response = client.put_object(
         Body=csv_content,
@@ -98,6 +152,15 @@ def write_to_s3(csv_content, bucket_name, file_path):
               reraise=True)
 @log_on_end(logging.INFO, "Writing {output_path:s} finished successfully")
 def write_output(output: List[Dict], output_path):
+    """! Writes prediction and evaluation results to S3 bucket.
+
+            Initially prepare results in csv format and calls write_to_s3() to write results.
+
+            Args:
+                output: List of results.
+                output_path: Path to save results in S3.
+
+    """
     bucket_name, file_path = parse_s3_url(output_path)
     with io.StringIO() as csvfile:
     # with open(output_path, 'w', newline='') as csvfile:
@@ -114,6 +177,18 @@ def write_output(output: List[Dict], output_path):
 
 
 def main(input_path: str, output_path: str):
+    """! Cloud evaluation main method.
+
+        Does the following:
+        - Loads csv input dataset
+        - Runs model on input dataset
+        - Write results to output_path
+
+        Args:
+            input_path: Path to input dataset
+            output_path: Path to results
+
+    """
     # Load CSV
     rows = load_csv(input_path)
     # Call model and evaluate on each row
@@ -123,6 +198,13 @@ def main(input_path: str, output_path: str):
 
 
 def download_file_from_s3(source_s3_url: str):
+    """! Downloads file from S3 using boto3 package.
+
+        Args:
+            source_s3_url: S3 Url
+        Returns:
+            file_stream - Downloaded file
+    """
     bucket_name, filepath = parse_s3_url(source_s3_url)
     s3 = boto3.client('s3', region_name='us-east-2')
     res = s3.get_object(Bucket=bucket_name, Key=filepath)['Body'].read()
@@ -131,6 +213,15 @@ def download_file_from_s3(source_s3_url: str):
 
 
 def parse_s3_url(s3_url: str):
+    """! Parse S3 url to bucket name and file path
+
+        Args:
+            s3_url: Url
+
+        Returns:
+            bucket_name - Bucket name
+            filepath - File path
+    """
     bucket_name, filepath = s3_url.split('//')[1].split('/', maxsplit=1)
     return bucket_name, filepath
 
@@ -145,7 +236,12 @@ def parse_s3_url(s3_url: str):
 if __name__ == '__main__':
     from cloud_eval.cloud_eval_client import CloudEvalClient
 
+    ## CLI argv parsed:
+    ## @param input_dataset_filename - Input dataset filename
+    ## @param output_dataset_filename - Output results filename
     input_dataset_filename, output_dataset_filename = sys.argv[1:1 + 2]
+    ## Instance of the CloudEvalClient
     service_client = CloudEvalClient()
+    ## 'predict' or 'parse' - depends on a specific project.
     endpoint_name = service_client.get_endpoint_name()
     main(input_dataset_filename, output_dataset_filename)
