@@ -17,23 +17,34 @@ from dsframework.base.common.functions import flatten, split_dataframe, get_date
 from tester.evaluator import generatedProjectNameEvaluator
 
 
-class generatedClass(ZIDS_Tester):
+##
+# @file
+# @brief generatedClass implementation of ZIDS_Tester base class.
 
+class generatedClass(ZIDS_Tester):
+    """Main purpose of this class is to support the 'local testing' feature in dsp, it allows to run the model
+    on a selected dataset from dsp. It implements ZIDS_Tester.
+    """
     def __init__(self):
         ZIDS_Tester.__init__(self)
+        ## Not used
         self.ready = False
+        ## Instance of the pipeline
         self.pipeline = generatedProjectNamePipeline()
+        ## Instance of the Evaluator class
         self.evaluator = generatedProjectNameEvaluator()
-        self.pred_name = ""  # Fill this according to the field received from the model, and remove this comment
-        self.target_name = "" # Fill this according to the field received from DSP, and remove this comment
+        ## Fill this according to the field received from the model, and remove this comment
+        self.pred_name = ""
+        ## Fill this according to the field received from DSP, and remove this comment
+        self.target_name = ""
 
     def test_batch(self, test_request: TestInputRequest) -> TestOutputResponse:
-        """
-        This is the main function of the tester, most of the functions are implemented in the
-        base class, but wherever needed, a NotImplementedError will be raised. Of course you can
-        feel free to mingle with the other functions as well. This is a humble suggestion.
+        """! This is the main function of the tester (Local testing feature in dsp), most of the functions
+        are implemented in the base class (ZIDS_Tester), but wherever needed, a NotImplementedError will be raised.
+        Feel free to mingle with the other functions as well. This is a humble suggestion.
 
-        Parameters:
+
+        Args:
             test_request: A request for testing a batch, as received from the DSP (Data Science Portal)
 
         Returns:
@@ -64,35 +75,39 @@ class generatedClass(ZIDS_Tester):
         return model_evaluation_results
 
     def create_model_request(self, batch_input_rows) -> generatedProjectNameInputs:
-        """
-        Structure the data as a proper request, and create a dictionary in order to enable serialization
-        This is an example code from the scoops project, please fit with your specific project fields
-        request_scoops = [ScoopCandidate(html_content=rec['text'],
-                                         source=rec['source'],
-                                         queue_name=rec['queue_name'],
-                                         title=rec['title']) for rec in batch_input_rows]
-        model_request = ScoopsClassificationRequest(pages=request_scoops)
+        """! Structure the data as a proper request, and create a dictionary in order to enable serialization.
 
-        Parameters:
+        Args:
             batch_input_rows: A batch of input information, intended to be structured into a model request
         Returns:
             model_request: The data, structured in a format that the model can work with
         """
+
+        ##
+        # This is an example code from the scoops project, please fit with your specific project fields:
+        # @code{.py}
+        # request_scoops = [ScoopCandidate(html_content=rec['text'],
+        #                   source=rec['source'],
+        #                   queue_name=rec['queue_name'],
+        #                   title=rec['title']) for rec in batch_input_rows]
+        # model_request = ScoopsClassificationRequest(pages=request_scoops)
+        # @endcode
+
         raise NotImplementedError
         model_request = generatedProjectNameInputs()
         return model_request
 
     @staticmethod
     def create_mock_response(input_request: TestInputRequest) -> List[TestOutputResponse]:
-        """
-        This function creates a mock output for the DSP to display.
+        """! This function creates a mock output for the DSP to display.
         When starting a new project, this function can be used to test connection with the DSP.
         It of course has to be modified in order to reflect the correct API fields
 
-        Parameters:
+
+        Args:
             input_request: Request as received from the DSP
         Returns:
-            A list of responses, to be sent back to the DSP
+            List[TestOutputResponse]: A list of responses, to be sent back to the DSP
         """
         input_request = input_request.dict()
         # print('DSP Request: ', input_request)
@@ -148,14 +163,15 @@ class generatedClass(ZIDS_Tester):
         return response
 
     def test_from_file(self, csv_file_path, batch_size):
-        """
-        Run an evaluation from a csv file input.
-        Parameters:
+        """! Run an evaluation from a csv file input.
+
+        Args:
             csv_file_path: csv file containing both ground truth and raw input for the model.
             batch_size: Size of batch to use in order to feed the model with controllable chunks of data
         """
-        # Define prediction and ground truth column names
+        ## Define prediction column name
         predictions_col_name = self.pred_name
+        ## Define ground truth column name
         ground_truth_col_name = self.target_name
 
         # Define csv output
